from setuptools import setup, find_packages

setup(
    name="hanifx",
    version="14.0.0",
    description="Hanifx: Irreversible encryption module for multiple programming languages",
    author="Hanif",
    author_email="sajim4653@gmail.com",
    url="https://github.com/hanifx-540/hanifx", 
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Topic :: Security :: Cryptography",
    ],
    python_requires='>=3.6',
    keywords="encryption irreversible python php java c ruby security",
)
